<template>
  <div class="map-search" :style="{ width: searchWidth }">
    <van-search
      class="search-container"
      v-model="keywords"
      :placeholder="'请输入' + type"
      show-action
      :disabled="type === '周边搜索范围'"
      @input="setKeywords"
      @search="onSearch"
      @clear="onClear"
      @focus="inputFocus = true"
    >
      <template #left>
        <van-icon name="arrow-left" style="margin-right: 16px" @click.prevent="back" />
        <div @click="showPiker">{{ type }}</div>
      </template>
      <template #action>
        <div v-if="inputFocus" @click="onSearch">搜索</div>
      </template>
    </van-search>
    <van-action-sheet
      v-model="showPicker"
      get-container="body"
      :actions="typeList"
      close-on-click-action
      @select="onSelect"
      @open="onOpen"
    />
    <van-action-sheet
      v-model="showRailPicker"
      get-container="body"
      :actions="railList"
      close-on-click-action
      @select="onSelectRail"
      @open="onOpenRail"
    />
    <van-list
      class="map-search-results"
      v-if="showResults"
      v-model="loading"
      :finished="finished"
      finished-text="没有更多了"
      @load="onLoad"
    >
      <van-cell v-for="item in resResult" :key="item.id" :title="item.name" @click="onClickCell(item)">
        <template #icon>
          <avatar v-if="type === '保安员'" size="40" style="margin-right: 8px">
            <div class="per-name">
              {{ item.name }}
            </div>
          </avatar>
          <van-image
            v-if="type === '驻勤点'"
            round
            width="40"
            height="40"
            :src="require('@/assets/images/mapSearch/驻勤点.png')"
          />
          <van-image v-if="type === '地点'" round width="24" height="24" :src="require('@/assets/images/mapSearch/地点.png')" />
        </template>
        <template #label>
          <div v-if="type === '保安员'" class="cell-label">
            <span><i class="icon icon-mobile"></i>{{ item.contact }}</span>
            <span><i class="icon icon-id"></i>{{ item.idCardNo }}</span>
          </div>
          <div v-if="type === '驻勤点'" class="cell-label">
            <p>{{ item.address }}</p>
            <p>{{ item.companyName }}</p>
          </div>
          <div v-if="type === '地点'" class="cell-label">
            <span>{{ item.address }}</span>
          </div>
        </template>
      </van-cell>
    </van-list>
  </div>
</template>

<script>
import { Search, ActionSheet, List, Cell, Image as VanImage, Notify, Icon } from "vant";
import address from "address";
import avatar from "@components/avatar.vue";
import { getEmployees } from "@/api/employee-controller";
import { getStations } from "@/api/security-station-controller";
import { ipLocation, place } from "@/api/amap";
import { mapState } from "vuex";
import _ from "lodash";

export default {
  name: "mapSearch",
  components: {
    [Search.name]: Search,
    [ActionSheet.name]: ActionSheet,
    [List.name]: List,
    [Cell.name]: Cell,
    [VanImage.name]: VanImage,
    [Notify.name]: Notify,
    [Icon.name]: Icon,
    avatar,
  },
  data() {
    return {
      value: "",
      keywords: "",
      type: "保安员",
      typeList: [
        { name: "保安员", text: "保安员", value: "保安员" },
        { name: "驻勤点", text: "驻勤点", value: "驻勤点" },
        { name: "地点", text: "地点", value: "地点" },
      ],
      showPicker: false,
      showRailPicker: false,
      list: [],
      resResult: [],
      loading: false,
      finished: false,
      showResults: false,
      inputFocus: false,
      railList: [{ name: "100" }, { name: "300" }, { name: "500" }],
      lastType: "",
      lastKeyword: "",
    };
  },
  computed: {
    ...mapState({
      rail: (state) => state.app.rail,
    }),
    searchWidth() {
      return this.inputFocus ? "351px" : "299px";
    },
  },
  watch: {
    inputFocus(value) {
      this.$emit("focusChange", value);
    },
  },
  methods: {
    onSearch() {
      if (this.keywords) {
        // this.showResults = true;
        this.onLoad();
      } else {
        this.showResults = false;
        // 警告通知
        Notify({ type: "warning", message: "请输入关键字" });
      }
    },
    onClear() {
      this.inputFocus = false;
      this.showResults = false;
    },
    back() {
      this.showResults = false;
      if (this.type === "周边搜索范围") {
        this.type = this.lastType;
        this.keywords = "";
      }
      if (!this.keywords) {
        this.inputFocus = false;
        this.$emit("clear");
      } else {
        this.keywords = "";
      }
      // if (lastType) {
      //   this.keywords = this.lastKeyword;
      // }
    },
    setKeywords() {},
    onSelect({ name }) {
      if (name !== this.type) {
        this.keywords = ""; // 类型切换后置空搜索内容
        this.showResults = false; // 隐藏上一次搜索结果
        this.type = name;
        this.$emit("select");
      }
    },
    onOpen() {
      this.$emit("open");
    },
    onSelectRail({ name }) {
      this.keywords = `${name}m`;
      // this.$store.commit("SET_RAIL", {
      //   distance: Number(name),
      // });
      this.$emit("railChange", Number(name));
    },
    onOpenRail() {},
    onLoad() {
      this.loading = false;
      if (this.type === "保安员") {
        this.searchEmployees();
      } else if (this.type === "驻勤点") {
        this.searchStations();
      } else if (this.type === "地点") {
        this.getPlace();
      }
    },
    onClickCell(data) {
      this.showResults = false;
      // 清空图标
      this.$emit("clearMap");
      console.log(data);
      this.hideAllList();
      if (this.type === "保安员") {
        this.$emit("clickEmployee", data);
      } else if (this.type === "驻勤点") {
        data.securityStationId = data.id;
        this.$emit("clickStation", data);
      } else if (this.type === "地点") {
        this.$emit("clickPoi", data);
      }
    },
    /**
     * @隐藏所有搜索结果列表框
     */
    hideAllList() {
      this.resResultShow = false;
    },
    parseStringToStar(str) {
      return str.length > 2 ? str.substr(0, 2) + new Array(str.length - 2).join("*") + str.substr(-2) : str;
    },
    //查询保安员
    async searchEmployees() {
      getEmployees({
        pageIndex: 1,
        pageSize: 100,
        keyword: this.keywords,
        searchModel: "Keyword",
        deskTypes: ["Normal", "Proprietor"],
      })
        .then((res) => {
          console.log(res);
          this.resResult = res;
          this.resResult.forEach((item) => {
            item["isIdCardNo"] = false;
            item["isContact"] = false;
            item["nameSlice"] = item.name.slice(-2);
            item["idCardNoHide"] = this.parseStringToStar(item.idCardNo);
            item["contactHide"] = this.parseStringToStar(item.contact);
            item["concatVisible"] = false;
            item["type"] = "employee";
          });
          // this.empoloyeesResultShow = true;
          this.showResults = true;
          this.finished = true;
          this.$emit("search", {
            type: 1,
            data: this.resResult,
          });
        })
        .catch((err) => {
          console.log(err);
        });
    },
    //查询驻勤点
    async searchStations() {
      getStations({
        pageIndex: 1,
        pageSize: 100,
        searchModel: "Name",
        stationTypes: [],
        keyword: this.keywords,
        deskTypes: ["Normal", "Proprietor"],
      })
        .then((res) => {
          console.log(res);
          this.resResult = res;
          // this.stationsResultShow = true;
          this.showResults = true;
          this.finished = true;
          this.$emit("search", {
            type: 2,
            data: this.resResult,
          });
        })
        .catch((err) => {
          console.log(err);
        });
    },
    //查询地址
    async getPlace() {
      const city = (await ipLocation(address.ip())) || "厦门";
      console.log(city);
      place({
        keywords: this.keywords,
        offset: 10,
        city,
      })
        .then((res) => {
          const { status, data } = res;
          if (status === 200) {
            console.log("poidata", data);
            this.resResult = data.tips
              .map((poi) => {
                return { ...poi, type: "location" };
              })
              .filter((x) => typeof x.id !== "object");
            console.log("locationresResult", this.resResult);
            // this.resResultShow = true;
            this.showResults = true;
            this.finished = true;
            this.$emit("search", {
              type: 3,
              data: this.resResult,
            });
          }
        })
        .catch((err) => {
          console.log(err);
        });
    },
    /**
     * @触发周边调度
     */
    dispatch() {
      this.lastType = this.type;
      this.type = "周边搜索范围";
      this.lastKeyword = _.clone(this.keywords);
      this.keywords = `${this.rail.distance}m`;
    },
    showPiker() {
      this.showPicker = false;
      this.showRailPicker = false;
      if (this.type === "周边搜索范围") {
        this.showRailPicker = true;
      } else {
        this.showPicker = true;
      }
    },
  },
};
</script>

<style scoped lang="less">
.map-search {
  //width: 299px;
  position: absolute;
  top: 44px;
  left: 15px;
  z-index: 2;
  .search-container {
    box-shadow: 0 2px 12px 0 rgba(0, 0, 0, 0.15);
    border-radius: 6px 6px 6px 6px;
    width: 100%;
  }
  &-results {
    margin-top: 2px;
    height: 600px;
    overflow-y: scroll; //设置这个 才能指定高度
    background: #ffffff;
    .per-name {
      height: 40px;
      width: 40px;
      background: #0e71ff;
      color: #fff;
      font-size: 12px;
      display: flex;
      align-items: center;
      justify-content: center;
    }
    .cell-label {
      display: flex;
      justify-content: space-between;
      flex-wrap: wrap;
      p {
        width: 100%;
        margin: 0;
        display: flex;
        align-items: center;
        .icon {
          width: 16px;
          height: 16px;
          display: inline-block;
          margin-right: 2px;
          &-mobile {
            background: url("~@/assets/images/mapSearch/电话.png") no-repeat;
            background-size: 100% 100%;
          }
          &-id {
            background: url("~@/assets/images/mapSearch/身份.png") no-repeat;
            background-size: 100% 100%;
          }
        }
      }
      span {
        display: flex;
        align-items: center;
        //justify-content: space-between;
        .icon {
          width: 16px;
          height: 16px;
          display: inline-block;
          margin-right: 2px;
          &-mobile {
            background: url("~@/assets/images/mapSearch/电话.png") no-repeat;
            background-size: 100% 100%;
          }
          &-id {
            background: url("~@/assets/images/mapSearch/身份.png") no-repeat;
            background-size: 100% 100%;
          }
        }
      }
    }
  }
}
</style>
